/*
 * This file contains all the necessary settings for the IQS324.
 * It can be changed from the GUI or edited here.
 * File:   IQS324_init.h
 * Author: Azoteq
 */

#ifndef IQS324_INIT_H
#define IQS324_INIT_H

/* System Control Settings */
/* Memory Map Position 0x1000 - 0x1011 */
#define AUTO_CLEAR_SETTINGS 0x00
#define SETTINGS_0 0x84
#define EVENTMASK 0x1D
#define ULP_SETTINGS 0x73
#define AUTO_ULP_THRESHOLD_0 0xC8
#define AUTO_ULP_THRESHOLD_1 0x00
#define HA_REPORT_0 0x02
#define HA_REPORT_1 0x00
#define NP_REPORT_0 0x14
#define NP_REPORT_1 0x00
#define LP_REPORT_0 0x64
#define LP_REPORT_1 0x00
#define ULP_REPORT_0 0xF4
#define ULP_REPORT_1 0x01
#define ULP_TIMEOUT_0 0x88
#define ULP_TIMEOUT_1 0x13
#define I2C_TIMEOUT_0 0xFA
#define I2C_TIMEOUT_1 0x00

/* Channel 0 Settings */
/* Memory Map Position 0x1014 - 0x102D */
#define CONVERSION_SETUP 0xCB
#define CONVERSION_SETTINGS 0x37
#define BUTTON_TOUCH_TIMEOUT_0 0x40
#define BUTTON_TOUCH_TIMEOUT_1 0x1F
#define BUTTON_DORMANCY_TIMEOUT_0 0xA0
#define BUTTON_DORMANCY_TIMEOUT_1 0x0F
#define BUTTON_ATI_TIMEOUT_0 0xE8
#define BUTTON_ATI_TIMEOUT_1 0x03
#define BUTTON_FILTER_COUNT_BETA 0x02
#define BUTTON_FILTER_LTA_BETA 0x08
#define BUTTON_FILTER_LTA_BETA_FAST 0x04
#define BUTTON_FILTER_LTA_LP_BETA 0x0A
#define BUTTON_FILTER_LTA_BETA_FAST_BAND_0 0x05
#define BUTTON_FILTER_LTA_BETA_FAST_BAND_1 0x00
#define BUTTON_THRESHOLD_0 0xC8
#define BUTTON_THRESHOLD_1 0x00
#define BUTTON_DEBOUNCE 0x12
#define BUTTON_PROX_HYST 0x14
#define MOVEMENT_THRESHOLD_0 0x32
#define MOVEMENT_THRESHOLD_1 0x00
#define MOVEMENT_DEBOUNCE 0x12
#define MOVEMENT_TOUCH_HYST 0x64
#define BUTTON_ATI_BAND_0 0xE8
#define BUTTON_ATI_BAND_1 0x03
#define BUTTON_LTA_HALT_THRESHOLD_0 0x64
#define BUTTON_LTA_HALT_THRESHOLD_1 0x00

/* Channel 0 ATI Settings */
/* Memory Map Position 0x102E - 0x1035 */
#define SENSOR0_ATI_BASE_0 0x98
#define SENSOR0_ATI_BASE_1 0x3A
#define SENSOR0_ATI_TARGET_0 0x64
#define SENSOR0_ATI_TARGET_1 0x19
#define SENSOR0_COARSE 0xCE
#define SENSOR0_FINE 0x4C
#define SENSOR0_COMPENSATION 0x31
#define SENSOR0_COMPENSATION_DIVIDER 0x7B

/* Hall Plate Settings */
/* Memory Map Position 0x1036 - 0x1047 */
#define NW_HALLPLATE_OFFSET_0 0xB3
#define NW_HALLPLATE_OFFSET_1 0x01
#define NE_HALLPLATE_OFFSET_0 0xC1
#define NE_HALLPLATE_OFFSET_1 0x01
#define SE_HALLPLATE_OFFSET_0 0xA0
#define SE_HALLPLATE_OFFSET_1 0x01
#define SW_HALLPLATE_OFFSET_0 0x35
#define SW_HALLPLATE_OFFSET_1 0x01
#define HALL_COARSE 0xE6
#define HALL_FINE 0x4D
#define HALL_TARGET_0 0xC8
#define HALL_TARGET_1 0x32
#define HALL_ATI_BAND_0 0xD0
#define HALL_ATI_BAND_1 0x07
#define HP_BIAS 0xDE
#define HP_SETTING 0x5B
#define RE_ATI_BLOCKING 0x03
#define HALL_INIT_SETTING 0x04

/* Hall Phase Angle */
/* Memory Map Position 0x1048 - 0x104B */
#define PHASE_SINE_0 0x1B
#define PHASE_SINE_1 0x4F
#define PHASE_COSE_0 0x77
#define PHASE_COSE_1 0xF3

/* Hall UI Settings */
/* Memory Map Position 0x1062 - 0x106D */
#define ROTATION_UI_SETTINGS_0 0x16
#define OPEN_QUAD 0x00
#define WHEEL_TO_MAGNET_ANGLE_0 0x92
#define WHEEL_TO_MAGNET_ANGLE_1 0xD1
#define HIGH_ACCURACY_TIMEOUT_0 0x2C
#define HIGH_ACCURACY_TIMEOUT_1 0x01
#define STATIONARY_TIMEOUT_0 0x88
#define STATIONARY_TIMEOUT_1 0x13
#define AUTO_ZERO_BETA 0x01
#define FILTER_BETA 0x0C
#define LP_FILTER_BETA 0x14
#define CORDIC_RESOLUTION 0x0E

/* Hall Interval Settings */
/* Memory Map Position 0x106E - 0x1073 */
#define NUMBER_INTERVALS_0 0x18
#define NUMBER_INTERVALS_1 0x00
#define INTERVAL_HYSTERESIS_0 0xFA
#define INTERVAL_HYSTERESIS_1 0x00
#define DEFAULT_HYSTERESIS_0 0x00
#define DEFAULT_HYSTERESIS_1 0x00

/* Normalisation Settings */
/* Memory Map Position 0x1074 - 0x1075 */
#define NORMILIZATION_BETA 0x02
#define NORMILIZATION_MODE 0x01

/* Spoof Settings */
/* Memory Map Position 0x1084 - 0x1084 */
#define SPOOF_COUNTS 0x00

#endif /* IQS324_INIT_H */
